import { bq as Json, br as ObjectStorage } from './uuid-79f1383b';
import { f as LogHandlerOptions, b as LogMessage, c as LogHandler } from './log-92407641';

declare type csvOptions = {
    /** @deprecated will probably be replaced by logLevel */
    debug?: boolean;
    path?: string;
    filename?: string;
    encoding?: BufferEncoding;
    prefix?: string;
    env?: Record<string, string>;
};
declare function stringToPath(value?: string, defaultValue?: string): string;
declare function valueToPath(value?: any, defaultValue?: string): string;
declare const toPath: typeof valueToPath;
declare function setupEnv(options?: csvOptions): {
    parsed: Record<string, string>;
    error?: undefined;
} | {
    error: unknown;
    parsed?: undefined;
};

interface FileStorageOptions {
    pretty?: boolean;
    path?: string;
    extension?: string;
    objectFromString?: (data: string) => any;
    objectToString?: (data: any) => string;
    keyToFilename?: (key: string) => string;
}
declare class FileStorage<T = Json> implements ObjectStorage<T> {
    private store;
    private dirname;
    private fileKeys?;
    private pretty;
    private extension;
    private extensionLength;
    private objectFromString;
    private objectToString;
    private keyToFilename;
    constructor(opt?: FileStorageOptions);
    setItem(key: string, value: T): void;
    getPath(key: string): string;
    getBuffer(key: string): Buffer;
    getItem(key: string): T | undefined;
    removeItem(key: string): void;
    clear(): void;
    allKeys(): string[];
}

declare function LoggerFileHandler(path: string, opt?: LogHandlerOptions): (msg: LogMessage) => void;

declare function colorString(value: string, colorCode: number): string;
declare function LoggerNodeHandler(opt?: LogHandlerOptions): LogHandler;

declare const _dirname: string;

export { FileStorageOptions as F, LoggerFileHandler as L, _dirname as _, setupEnv as a, FileStorage as b, colorString as c, LoggerNodeHandler as d, stringToPath as s, toPath as t, valueToPath as v };
